@@ -4,7 +4,5 @@ from django.http import HttpResponse
 from .compat import patterns
 
 urlpatterns = patterns(
-    '',
-    url(r'^overridden_url/$',
-        lambda r: HttpResponse('Overridden urlconf works!'))
+    "", url(r"^overridden_url/$", lambda r: HttpResponse("Overridden urlconf works!"))
 )
